==> mozc-2.17.2313.102.tar.xz: mozc-2.17.2313.102/src/gui/config_dialog/character_form_editor.h <==
// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_
#define MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_

#include <QtGui/QTableWidget>

#include <memory>

#include "base/port.h"
#include "protocol/config.pb.h"

namespace mozc {
namespace config {
class Config;
}

namespace gui {

class ComboBoxDelegate;

class CharacterFormEditor : public QTableWidget {
  Q_OBJECT
 public:
  explicit CharacterFormEditor(QWidget *parent = NULL);
  virtual ~CharacterFormEditor();

  void Load(const config::Config &config);
  void Save(config::Config *config);

 private:
  std::unique_ptr<ComboBoxDelegate> delegate_;
};

}  // namespace gui
}  // namespace mozc

#if defined UI_CONFIG_DIALOG_H
using mozc::gui::CharacterFormEditor;
#endif

#endif  // MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_

==> mozc-2.26.4282.100.tar.xz: mozc-2.26.4282.100/src/gui/config_dialog/character_form_editor.h <==
// Copyright 2010-2021, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_
#define MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_

#include <QtWidgets/QTableWidget>
#include <memory>

#include "base/port.h"
#include "protocol/config.pb.h"

namespace mozc {
namespace config {
class Config;
}

namespace gui {

class ComboBoxDelegate;

class CharacterFormEditor : public QTableWidget {
  Q_OBJECT
 public:
  explicit CharacterFormEditor(QWidget *parent = nullptr);
  ~CharacterFormEditor() override;

  void Load(const config::Config &config);
  void Save(config::Config *config);

 private:
  std::unique_ptr<ComboBoxDelegate> delegate_;
};

}  // namespace gui
}  // namespace mozc

#if defined UI_CONFIG_DIALOG_H
using mozc::gui::CharacterFormEditor;
#endif

#endif  // MOZC_GUI_CONFIG_DIALOG_CHARACTER_FORM_EDITOR_H_
